/**
 * @module botbuilder-testing
 */
/**
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
import { Middleware, TurnContext } from 'botbuilder-core';
/**
 * Logger describes something that can log data, i.e. console
 */
export interface Logger {
    /**
     * Log some data
     */
    log: (...args: unknown[]) => void;
}
/**
 * Log a transcript of messages from a dialog to the console, along with additional diagnostic information.
 * For use with the `DialogTestClient` class.
 *
 * Example:
 * ```javascript
 * let client = new DialogTestClient(DIALOG, OPTIONS, [new DialogTestLogger()]);
 * ```
 */
export declare class DialogTestLogger implements Middleware {
    private readonly logger;
    private _stopwatchStateKey;
    /**
     * Initializes a new instance of the [DialogTestLogger](xref:botbuilder-testing.DialogTestLogger) class.
     *
     * @param logger A logger object with a `log` function.
     */
    constructor(logger?: Logger);
    /**
     * Called each time the bot receives a new request.
     *
     * @param context [TurnContext](xref:botbuilder-core.TurnContext) for current turn of conversation with the user.
     * @param next Function to call to continue execution to the next step in the middleware chain.
     * @returns A `Promise` that represents the work queued to execute.
     */
    onTurn(context: TurnContext, next: () => Promise<void>): Promise<void>;
}
//# sourceMappingURL=dialogTestLogger.d.ts.map
